@@ -2,10 +2,11 @@ package inc::MakeMaker;
 
 use Moose;
 use namespace::autoclean;
-use v5.10;
 
 with 'Dist::Zilla::Role::InstallTool';
 
+my $checks;
+
 sub setup_installer
 {
   my($self) = @_;
@@ -14,7 +15,6 @@ sub setup_installer
   
   my $content = $makefile->content;
   
-  state $checks;
   unless($checks)
   {
     $checks = do { local $/; <DATA> };
@@ -36,7 +36,7 @@ sub setup_installer
 __DATA__
 
 my $sep = $^O eq 'MSWin32' ? ';' : ':';
-my $ext = $^O =~ /^(MSWin32|cygwin)$/ ? '.exe' : '';
+my $ext = $^O =~ /^(MSWin32|cygwin|msys)$/ ? '.exe' : '';
 my %found;
 foreach my $path (split $sep, $ENV{PATH})
 {
@@ -55,6 +55,10 @@ foreach my $program (qw( mv cp rm ))
   warn "not found: $program" unless $found{$program};
 }
 
+# On Windows we use ppt implementation of some of these
+# if they are not found i nthe path.
+$found{cp} = $found{rm} = $found{mv} = $found{touch} = 1 if $^O eq 'MSWin32';
+
 unless($found{mv} && $found{cp} && $found{rm})
 {
   warn "this distribution requires GNU Coreutils (mv, cp, rm and ln), or equivalent";
